# -*- coding: utf-8 -*-
'''
@Time    : /
@Author  : Yanyuxiang
@Email   : yanyuxiangtoday@163.com
@FileName: /
@Software: PyCharm
'''

import cv2

def info(mp4_path):
    '''
    this func get and print video info using cv2

    :param video_path: path to video
    :return: fps, total frames, image width, image height
    '''

    cap = cv2.VideoCapture(mp4_path)
    fps = cap.get(cv2.CAP_PROP_FPS)
    frame_count = cap.get(cv2.CAP_PROP_FRAME_COUNT)
    width = int(cap.get(cv2.CAP_PROP_FRAME_WIDTH))
    height = int(cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
    print('----------------------------------------------------------------------------------------------------')
    print('info fps {:.5f}, frameCnt {:^9}, width {:^5}, height {:^5}, time len {:0>2d}:{:0>2d}:{:0>2d}'.format(
        fps,
        frame_count,
        width,
        height,
        int((frame_count / fps) // 3600),
        int(((frame_count / fps) % 3600 ) // 60),
        int(((frame_count / fps) % 3600) % 60)))
    return fps, frame_count, width, height


# -*- coding: utf-8 -*-
'''
@Time    : /
@Author  : Yanyuxiang
@Email   : yanyuxiangtoday@163.com
@FileName: /
@Software: PyCharm
'''

from . import list
from . import video
from . import file
from .utils import *



# -*- coding: utf-8 -*-
'''
@Time    : /
@Author  : Yanyuxiang
@Email   : yanyuxiangtoday@163.com
@FileName: /
@Software: PyCharm
'''

import os
import numpy as np

def save(dump_path,
         content,
         keep_ori):
    '''
    save str/np.array to txt or csv

    :param dump_path: path to save file
    :param content:   content to save, it could be str or np.array2d
    :param keep_ori:  if True, it will add content at the tail of thr file, else will delte ori file
    :return:          None
    '''

    keep_ori = (keep_ori == 'True') if isinstance(keep_ori, str) else keep_ori

    os.system(f'rm {dump_path}') if not keep_ori and os.path.exists(dump_path) else None

    if dump_path[-4:] != '.txt' and dump_path[-4:] != '.csv':
        raise Exception('wrong type to save')

    if isinstance(content, str):
        with open(dump_path, 'a') as dump_file:
            dump_file.write(content)
    elif isinstance(content, type(np.array(0.0))):
            np.savetxt(dump_path, content, fmt='%.5f', delimiter=',')
    else:
        raise Exception('wrong content type')

    return




# -*- coding: utf-8 -*-
'''
@Time    : 2021/8/13
@Author  : Yanyuxiang
@Email   : yanyuxiangtoday@163.com
@FileName: utils.py
@Software: PyCharm
'''

import os
import yaml
from attrdict import AttrDict

def checkdir(dir_path):
    '''
    make dir if not exist

    :param dir_path: dir path to check
    :return: None
    '''
    os.makedirs(dir_path) if not os.path.isdir(dir_path) else None
    return

def load_yaml(yaml_path):
    # load config
    with open(yaml_path, 'r') as fopen:
        cfg = yaml.load(fopen)
        show_config(cfg)
        return AttrDict(cfg)

def _show_config(cur_dict, type):
    print('----------------------------------------------------------------------------------------------------')
    print(f'{type} config')
    key_list = list(cur_dict.keys())
    for k in key_list:
        print(f'--{k:20}: {cur_dict[k]}')
    return

def show_config(cfg):
    # current cfg is a dict
    key_list = list(cfg.keys())
    for k in key_list:
        _show_config(cfg[k], k)
    return



# -*- coding: utf-8 -*-
'''
@Time    : /
@Author  : Yanyuxiang
@Email   : yanyuxiangtoday@163.com
@FileName: /
@Software: PyCharm
'''

def rm_elem(input_list,
            elem=None):
    '''
    remove elem from input_list if elem in input_list,
    if not elem, will remove '.DS_Store'.

    :param input_list: list to remove elem
    :param elem:       elem ot remove in list
    :return:           None
    '''
    if elem:
        input_list.remove(elem) if elem in input_list else None
    else:
        input_list.remove('.DS_Store') if '.DS_Store' in input_list else None
    return



# -*- coding: utf-8 -*-
'''
@Time    : /
@Author  : Yanyuxiang
@Email   : yanyuxiangtoday@163.com
@FileName: /
@Software: PyCharm
'''

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="yyx_tools",
    version="0.0.14",
    author="yanyuxiangtoday",
    author_email="yanyuxiangtoday@163.com",
    description="tools for algorithm engineer",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yanyuxiangToday/yyx_tools",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)